/* Main function for root server.
   Copyright (C) 2003 Free Software Foundation, Inc.
   This file is part of the GNU Hurd.

   The GNU Hurd is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU Hurd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

#include <l4/thread.h>

#include "printf.h"

void
print_thread (l4_thread_id_t thread)
{
  if (l4_is_nil_thread (thread))
    printf ("nilthread");
  else if (l4_is_local_id (thread))
    printf ("Local 0x%x", thread.local);
  else
    printf ("No 0x%x Version 0x%x", thread.thread_no, thread.version);
}


int
main (void)
{
  l4_word_t data[4];
  cls ();

  printf ("Thread ID: ");
  print_thread (l4_myself ());
  printf (" ");
  print_thread (l4_my_local_id ());
  printf ("\n");

  printf ("Processor: %u\n", l4_processor_no ());

  printf ("Pager ID: ");
  print_thread (l4_pager ());
  printf ("\n");

  printf ("Exception Handler ID: ");
  print_thread (l4_exception_handler ());
  printf ("\n");

  printf ("User Defined Handle: 0x%x\n", l4_user_defined_handle ());

  printf ("Error Code: 0x%x\n", l4_error_code ());

  printf ("Xfer Timeout: %u\n", l4_xfer_timeout ());

  printf ("Intended Receiver: ");
  print_thread (l4_intended_receiver ());
  printf ("\n");

  printf ("Actual Sender: ");
  print_thread (l4_actual_sender ());
  printf ("\n");

  l4_store_mrs (0, 4, data);
  printf ("MR: [0] 0x%x  [1] 0x%x  [2] 0x%x  [3] 0x%x ...\n",
	  data[0], data[1], data[2], data[3]);

  l4_store_brs (0, 4, data);
  printf ("BR: [0] 0x%x  [1] 0x%x  [2] 0x%x  [3] 0x%x ...\n",
	  data[0], data[1], data[2], data[3]);

  return 0;
}
